import { presetCommon } from "./common.js";
import { presetEverything } from "./everything.js";
import { presetMinimal } from "./minimal.js";
import * as bingo_stratum762 from "bingo-stratum";
import * as zod633 from "zod";

//#region src/presets/index.d.ts
declare const presets: {
  common: bingo_stratum762.Preset<{
    access: zod633.ZodUnion<[zod633.ZodLiteral<"public">, zod633.ZodLiteral<"restricted">]>;
    author: zod633.ZodOptional<zod633.ZodString>;
    bin: zod633.ZodOptional<zod633.ZodUnion<[zod633.ZodString, zod633.ZodRecord<zod633.ZodString, zod633.ZodString>]>>;
    contributors: zod633.ZodOptional<zod633.ZodArray<zod633.ZodObject<{
      avatar_url: zod633.ZodString;
      contributions: zod633.ZodArray<zod633.ZodString, "many">;
      login: zod633.ZodString;
      name: zod633.ZodString;
      profile: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod633.ZodDefault<zod633.ZodString>;
    directory: zod633.ZodString;
    documentation: zod633.ZodObject<{
      development: zod633.ZodOptional<zod633.ZodString>;
      readme: zod633.ZodObject<{
        additional: zod633.ZodOptional<zod633.ZodString>;
        explainer: zod633.ZodOptional<zod633.ZodString>;
        footnotes: zod633.ZodOptional<zod633.ZodString>;
        usage: zod633.ZodOptional<zod633.ZodString>;
      }, "strip", zod633.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod633.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod633.ZodEffects<zod633.ZodUnion<[zod633.ZodString, zod633.ZodObject<{
      github: zod633.ZodString;
      npm: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod633.ZodOptional<zod633.ZodString>;
    existingLabels: zod633.ZodOptional<zod633.ZodArray<zod633.ZodObject<{
      color: zod633.ZodString;
      description: zod633.ZodString;
      name: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod633.ZodOptional<zod633.ZodString>;
    guide: zod633.ZodOptional<zod633.ZodObject<{
      href: zod633.ZodString;
      title: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod633.ZodOptional<zod633.ZodArray<zod633.ZodString, "many">>;
    logo: zod633.ZodOptional<zod633.ZodObject<{
      alt: zod633.ZodString;
      height: zod633.ZodOptional<zod633.ZodNumber>;
      src: zod633.ZodString;
      width: zod633.ZodOptional<zod633.ZodNumber>;
    }, "strip", zod633.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod633.ZodObject<{
      minimum: zod633.ZodString;
      pinned: zod633.ZodOptional<zod633.ZodString>;
    }, "strip", zod633.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod633.ZodString;
    packageData: zod633.ZodOptional<zod633.ZodObject<{
      dependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      devDependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      peerDependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      peerDependenciesMeta: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodUnknown>>;
      scripts: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodOptional<zod633.ZodString>>>;
    }, "strip", zod633.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod633.ZodOptional<zod633.ZodString>;
    repository: zod633.ZodString;
    rulesetId: zod633.ZodOptional<zod633.ZodString>;
    title: zod633.ZodString;
    type: zod633.ZodOptional<zod633.ZodUnion<[zod633.ZodLiteral<"commonjs">, zod633.ZodLiteral<"module">]>>;
    version: zod633.ZodOptional<zod633.ZodString>;
    words: zod633.ZodOptional<zod633.ZodArray<zod633.ZodString, "many">>;
    workflowsVersions: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodRecord<zod633.ZodString, zod633.ZodObject<{
      hash: zod633.ZodOptional<zod633.ZodString>;
      pinned: zod633.ZodOptional<zod633.ZodBoolean>;
    }, "strip", zod633.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
  everything: bingo_stratum762.Preset<{
    access: zod633.ZodUnion<[zod633.ZodLiteral<"public">, zod633.ZodLiteral<"restricted">]>;
    author: zod633.ZodOptional<zod633.ZodString>;
    bin: zod633.ZodOptional<zod633.ZodUnion<[zod633.ZodString, zod633.ZodRecord<zod633.ZodString, zod633.ZodString>]>>;
    contributors: zod633.ZodOptional<zod633.ZodArray<zod633.ZodObject<{
      avatar_url: zod633.ZodString;
      contributions: zod633.ZodArray<zod633.ZodString, "many">;
      login: zod633.ZodString;
      name: zod633.ZodString;
      profile: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod633.ZodDefault<zod633.ZodString>;
    directory: zod633.ZodString;
    documentation: zod633.ZodObject<{
      development: zod633.ZodOptional<zod633.ZodString>;
      readme: zod633.ZodObject<{
        additional: zod633.ZodOptional<zod633.ZodString>;
        explainer: zod633.ZodOptional<zod633.ZodString>;
        footnotes: zod633.ZodOptional<zod633.ZodString>;
        usage: zod633.ZodOptional<zod633.ZodString>;
      }, "strip", zod633.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod633.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod633.ZodEffects<zod633.ZodUnion<[zod633.ZodString, zod633.ZodObject<{
      github: zod633.ZodString;
      npm: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod633.ZodOptional<zod633.ZodString>;
    existingLabels: zod633.ZodOptional<zod633.ZodArray<zod633.ZodObject<{
      color: zod633.ZodString;
      description: zod633.ZodString;
      name: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod633.ZodOptional<zod633.ZodString>;
    guide: zod633.ZodOptional<zod633.ZodObject<{
      href: zod633.ZodString;
      title: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod633.ZodOptional<zod633.ZodArray<zod633.ZodString, "many">>;
    logo: zod633.ZodOptional<zod633.ZodObject<{
      alt: zod633.ZodString;
      height: zod633.ZodOptional<zod633.ZodNumber>;
      src: zod633.ZodString;
      width: zod633.ZodOptional<zod633.ZodNumber>;
    }, "strip", zod633.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod633.ZodObject<{
      minimum: zod633.ZodString;
      pinned: zod633.ZodOptional<zod633.ZodString>;
    }, "strip", zod633.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod633.ZodString;
    packageData: zod633.ZodOptional<zod633.ZodObject<{
      dependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      devDependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      peerDependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      peerDependenciesMeta: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodUnknown>>;
      scripts: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodOptional<zod633.ZodString>>>;
    }, "strip", zod633.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod633.ZodOptional<zod633.ZodString>;
    repository: zod633.ZodString;
    rulesetId: zod633.ZodOptional<zod633.ZodString>;
    title: zod633.ZodString;
    type: zod633.ZodOptional<zod633.ZodUnion<[zod633.ZodLiteral<"commonjs">, zod633.ZodLiteral<"module">]>>;
    version: zod633.ZodOptional<zod633.ZodString>;
    words: zod633.ZodOptional<zod633.ZodArray<zod633.ZodString, "many">>;
    workflowsVersions: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodRecord<zod633.ZodString, zod633.ZodObject<{
      hash: zod633.ZodOptional<zod633.ZodString>;
      pinned: zod633.ZodOptional<zod633.ZodBoolean>;
    }, "strip", zod633.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
  minimal: bingo_stratum762.Preset<{
    access: zod633.ZodUnion<[zod633.ZodLiteral<"public">, zod633.ZodLiteral<"restricted">]>;
    author: zod633.ZodOptional<zod633.ZodString>;
    bin: zod633.ZodOptional<zod633.ZodUnion<[zod633.ZodString, zod633.ZodRecord<zod633.ZodString, zod633.ZodString>]>>;
    contributors: zod633.ZodOptional<zod633.ZodArray<zod633.ZodObject<{
      avatar_url: zod633.ZodString;
      contributions: zod633.ZodArray<zod633.ZodString, "many">;
      login: zod633.ZodString;
      name: zod633.ZodString;
      profile: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod633.ZodDefault<zod633.ZodString>;
    directory: zod633.ZodString;
    documentation: zod633.ZodObject<{
      development: zod633.ZodOptional<zod633.ZodString>;
      readme: zod633.ZodObject<{
        additional: zod633.ZodOptional<zod633.ZodString>;
        explainer: zod633.ZodOptional<zod633.ZodString>;
        footnotes: zod633.ZodOptional<zod633.ZodString>;
        usage: zod633.ZodOptional<zod633.ZodString>;
      }, "strip", zod633.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod633.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod633.ZodEffects<zod633.ZodUnion<[zod633.ZodString, zod633.ZodObject<{
      github: zod633.ZodString;
      npm: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod633.ZodOptional<zod633.ZodString>;
    existingLabels: zod633.ZodOptional<zod633.ZodArray<zod633.ZodObject<{
      color: zod633.ZodString;
      description: zod633.ZodString;
      name: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod633.ZodOptional<zod633.ZodString>;
    guide: zod633.ZodOptional<zod633.ZodObject<{
      href: zod633.ZodString;
      title: zod633.ZodString;
    }, "strip", zod633.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod633.ZodOptional<zod633.ZodArray<zod633.ZodString, "many">>;
    logo: zod633.ZodOptional<zod633.ZodObject<{
      alt: zod633.ZodString;
      height: zod633.ZodOptional<zod633.ZodNumber>;
      src: zod633.ZodString;
      width: zod633.ZodOptional<zod633.ZodNumber>;
    }, "strip", zod633.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod633.ZodObject<{
      minimum: zod633.ZodString;
      pinned: zod633.ZodOptional<zod633.ZodString>;
    }, "strip", zod633.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod633.ZodString;
    packageData: zod633.ZodOptional<zod633.ZodObject<{
      dependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      devDependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      peerDependencies: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodString>>;
      peerDependenciesMeta: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodUnknown>>;
      scripts: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodOptional<zod633.ZodString>>>;
    }, "strip", zod633.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod633.ZodOptional<zod633.ZodString>;
    repository: zod633.ZodString;
    rulesetId: zod633.ZodOptional<zod633.ZodString>;
    title: zod633.ZodString;
    type: zod633.ZodOptional<zod633.ZodUnion<[zod633.ZodLiteral<"commonjs">, zod633.ZodLiteral<"module">]>>;
    version: zod633.ZodOptional<zod633.ZodString>;
    words: zod633.ZodOptional<zod633.ZodArray<zod633.ZodString, "many">>;
    workflowsVersions: zod633.ZodOptional<zod633.ZodRecord<zod633.ZodString, zod633.ZodRecord<zod633.ZodString, zod633.ZodObject<{
      hash: zod633.ZodOptional<zod633.ZodString>;
      pinned: zod633.ZodOptional<zod633.ZodBoolean>;
    }, "strip", zod633.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
};
//#endregion
export { presetCommon, presetEverything, presetMinimal, presets };
//# sourceMappingURL=index.d.ts.map